[Libreoffice-commits] core.git: 17 commits - include/sal include/tools Repository.mk scp2/AutoInstall.mk scp2/inc scp2/InstallModule_base.mk scp2/InstallModule_calc.mk scp2/InstallModule_crashrep.mk scp2/InstallModule_draw.mk scp2/InstallModule_impress.mk scp2/InstallModule_math.mk scp2/InstallModule_ooo.mk scp2/InstallModule_writer.mk scp2/source sc/source solenv/bin svx/source sw/source

Michael Stahl mstahl at redhat.com
Wed Oct 29 03:46:33 PDT 2014


 Repository.mk                                       |   93 +++++++++++++++-----
 include/sal/log-areas.dox                           |    1 
 include/tools/debug.hxx                             |    6 -
 sc/source/filter/excel/tokstack.cxx                 |   10 +-
 sc/source/filter/excel/xiescher.cxx                 |    2 
 scp2/AutoInstall.mk                                 |   14 ++-
 scp2/InstallModule_base.mk                          |    1 
 scp2/InstallModule_calc.mk                          |    5 -
 scp2/InstallModule_crashrep.mk                      |    4 
 scp2/InstallModule_draw.mk                          |    4 
 scp2/InstallModule_impress.mk                       |    1 
 scp2/InstallModule_math.mk                          |    5 -
 scp2/InstallModule_ooo.mk                           |    1 
 scp2/InstallModule_writer.mk                        |    5 -
 scp2/inc/macros.inc                                 |    2 
 scp2/source/base/file_base.scp                      |   13 --
 scp2/source/base/folderitem_base.scp                |    4 
 scp2/source/base/module_base.scp                    |    3 
 scp2/source/calc/file_calc.scp                      |    4 
 scp2/source/calc/folderitem_calc.scp                |    4 
 scp2/source/calc/module_calc.scp                    |    3 
 scp2/source/crashrep/file_crashrep.scp              |   18 ---
 scp2/source/draw/file_draw.scp                      |    4 
 scp2/source/draw/folderitem_draw.scp                |    4 
 scp2/source/draw/module_draw.scp                    |    4 
 scp2/source/impress/file_impress.scp                |    4 
 scp2/source/impress/folderitem_impress.scp          |    4 
 scp2/source/impress/module_impress.scp              |    3 
 scp2/source/math/file_math.scp                      |    4 
 scp2/source/math/folderitem_math.scp                |    4 
 scp2/source/math/module_math.scp                    |    3 
 scp2/source/ooo/common_brand.scp                    |   69 +-------------
 scp2/source/ooo/folderitem_ooo.scp                  |    8 -
 scp2/source/ooo/module_pdfimport.scp                |    8 -
 scp2/source/python/file_python.scp                  |   12 --
 scp2/source/writer/file_writer.scp                  |   13 --
 scp2/source/writer/folderitem_writer.scp            |    4 
 scp2/source/writer/module_writer.scp                |    3 
 solenv/bin/modules/installer/setupscript.pm         |    5 -
 svx/source/sidebar/paragraph/ParaPropertyPanel.cxx  |    2 
 svx/source/sidebar/possize/PosSizePropertyPanel.cxx |    2 
 sw/source/core/bastyp/swcache.cxx                   |    4 
 sw/source/core/doc/tblrwcl.cxx                      |   14 ++-
 sw/source/core/layout/ftnfrm.cxx                    |   20 ----
 sw/source/core/text/inftxt.cxx                      |   20 ++--
 sw/source/core/text/inftxt.hxx                      |   23 ++--
 sw/source/core/text/itrform2.cxx                    |   10 +-
 sw/source/core/text/itrtxt.cxx                      |    6 -
 sw/source/core/text/porfly.cxx                      |    2 
 sw/source/core/text/porrst.cxx                      |    8 -
 sw/source/core/text/txthyph.cxx                     |    2 
 sw/source/core/view/viewsh.cxx                      |    9 -
 sw/source/filter/ww8/ww8par.cxx                     |    2 
 sw/source/filter/ww8/ww8par.hxx                     |    2 
 sw/source/filter/ww8/ww8par2.hxx                    |    4 
 sw/source/filter/ww8/ww8par6.cxx                    |   24 ++---
 sw/source/uibase/sidebar/PagePropertyPanel.cxx      |    2 
 57 files changed, 242 insertions(+), 273 deletions(-)

New commits:
commit 25bfdffdacadad812f3cebdbc537687c9c59541b
Author: Michael Stahl <mstahl at redhat.com>
Date:   Wed Oct 29 11:04:35 2014 +0100

    scp2: remove EXENAME
    
    Change-Id: I045a65d4efbaf8fcb55318ffce4f8929e2fbbe15

diff --git a/scp2/inc/macros.inc b/scp2/inc/macros.inc
index d2142bd..d8c7370 100644
--- a/scp2/inc/macros.inc
+++ b/scp2/inc/macros.inc
@@ -57,10 +57,8 @@
 #endif
 
 #ifdef UNX
-    #define EXENAME(name)                     STRING(name)
     #define PROFILENAME(name)                 STRING(CONCAT2(name,rc))
 #else
-    #define EXENAME(name)                     STRING(CONCAT2(name,.exe))
     #define PROFILENAME(name)                 STRING(CONCAT2(name,.ini))
 #endif
 
commit a77ef6c0e4e6096b073552d98b405bda62a8950c
Author: Michael Stahl <mstahl at redhat.com>
Date:   Wed Oct 29 00:11:29 2014 +0100

    scp2: move writer executables to AutoInstall
    
    Change-Id: Ibcfdd7a8c204a1ec90045ad39ef456237ba80a34

diff --git a/Repository.mk b/Repository.mk
index 66efa4a..628a71a 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -128,6 +128,13 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,math_brand, \
 	) \
 ))
 
+$(eval $(call gb_Helper_register_executables_for_install,OOO,writer_brand, \
+	$(if $(filter WNT,$(OS)), \
+		sweb \
+		swriter \
+	) \
+))
+
 $(eval $(call gb_Helper_register_executables_for_install,OOO,ooo, \
 	gengal \
 ))
@@ -171,8 +178,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(filter WNT,$(OS)), \
 		quickstart \
 		senddoc \
-		sweb \
-		swriter \
 	) \
 ))
 
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index 0970011..0cd2268 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -47,5 +47,6 @@ $(eval $(call gb_AutoInstall_add_module,winexplorerextwin64,SHLXTHDL_LIB_FILE_CO
 $(eval $(call gb_AutoInstall_add_module,winexplorerextwin64nt6,SHLXTHDL_LIB_FILE_COMPONENTCONDITION,,,"VersionNT64 >= 600"))
 endif
 $(eval $(call gb_AutoInstall_add_module,writer,LIBO_LIB_FILE))
+$(eval $(call gb_AutoInstall_add_module,writer_brand,,LIBO_EXECUTABLE))
 
 # vim: set noet sw=4 ts=4:
diff --git a/scp2/InstallModule_writer.mk b/scp2/InstallModule_writer.mk
index 69ccf5e..cfc4d9a 100644
--- a/scp2/InstallModule_writer.mk
+++ b/scp2/InstallModule_writer.mk
@@ -9,7 +9,10 @@
 
 $(eval $(call gb_InstallModule_InstallModule,scp2/writer))
 
-$(eval $(call gb_InstallModule_use_auto_install_libs,scp2/writer,writer))
+$(eval $(call gb_InstallModule_use_auto_install_libs,scp2/writer,\
+	writer \
+	writer_brand \
+))
 
 $(eval $(call gb_InstallModule_define_if_set,scp2/writer,\
 	ENABLE_MACOSX_SANDBOX \
diff --git a/scp2/source/writer/file_writer.scp b/scp2/source/writer/file_writer.scp
index 5653c6d..280e40a 100644
--- a/scp2/source/writer/file_writer.scp
+++ b/scp2/source/writer/file_writer.scp
@@ -18,20 +18,11 @@
 
 #include "macros.inc"
 
-#ifndef MACOSX
+#if !defined MACOSX && !defined WNT
 File gid_File_Exe_Swriter
     BIN_FILE_BODY;
     Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(swriter);
-    Styles = (PACKED);
-End
-#endif
-
-#ifdef WNT
-File gid_File_Exe_Sweb
-    BIN_FILE_BODY;
-    Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(sweb);
+    Name = "swriter";
     Styles = (PACKED);
 End
 #endif
diff --git a/scp2/source/writer/folderitem_writer.scp b/scp2/source/writer/folderitem_writer.scp
index c4f8dbf..306fc88 100644
--- a/scp2/source/writer/folderitem_writer.scp
+++ b/scp2/source/writer/folderitem_writer.scp
@@ -23,8 +23,8 @@ FolderItem gid_Folderitem_Swriter
     Name = "%PRODUCTNAME Writer";
     ModuleID = gid_Module_Prg_Wrt_Bin;
     FolderID = gid_Folder_Staroffice51;
-    FileID = gid_File_Exe_Swriter;
-    IconFile = gid_File_Exe_Swriter;
+    FileID = auto_writer_brand_exe_swriter;
+    IconFile = auto_writer_brand_exe_swriter;
     IconID = 0;
     WkDir = gid_Brand_Dir_Program;
     Parameter = "";
diff --git a/scp2/source/writer/module_writer.scp b/scp2/source/writer/module_writer.scp
index 75b8c04..987a7c7 100644
--- a/scp2/source/writer/module_writer.scp
+++ b/scp2/source/writer/module_writer.scp
@@ -19,6 +19,7 @@
 #include "macros.inc"
 
 #include "AutoInstall/writer"
+#include "AutoInstall/writer_brand"
 
 Module gid_Module_Prg_Wrt
     MOD_NAME_DESC(MODULE_PRG_WRT);
@@ -55,7 +56,7 @@ Module gid_Module_Brand_Prg_Wrt
     Minimal = YES;
     Default = YES;
     Styles = (HIDDEN_ROOT);
-    Files = (gid_File_Exe_Swriter,gid_File_Exe_Sweb);
+    Files = (auto_writer_brand_ALL,gid_File_Exe_Swriter);
 End
 
 Module gid_Module_Langpack_Writer_Template
commit 30047f28bf0ae8b53dc175ae09350b342159d644
Author: Michael Stahl <mstahl at redhat.com>
Date:   Wed Oct 29 00:02:58 2014 +0100

    scp2: move math executables to AutoInstall
    
    Change-Id: I8cb04121c52eb62e837c6a80037f9eabfc573dde

diff --git a/Repository.mk b/Repository.mk
index 182652c..66efa4a 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -122,6 +122,12 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,impress_brand, \
 	) \
 ))
 
+$(eval $(call gb_Helper_register_executables_for_install,OOO,math_brand, \
+	$(if $(filter WNT,$(OS)), \
+		smath \
+	) \
+))
+
 $(eval $(call gb_Helper_register_executables_for_install,OOO,ooo, \
 	gengal \
 ))
@@ -165,7 +171,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(filter WNT,$(OS)), \
 		quickstart \
 		senddoc \
-		smath \
 		sweb \
 		swriter \
 	) \
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index 23d56a0..0970011 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -27,6 +27,7 @@ $(eval $(call gb_AutoInstall_add_module,impress,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,impress_brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,kde,LIBO_LIB_FILE,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,math,LIBO_LIB_FILE))
+$(eval $(call gb_AutoInstall_add_module,math_brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,ogltrans,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,onlineupdate,LIBO_LIB_FILE_COMPONENTCONDITION,,,"ISCHECKFORPRODUCTUPDATES=1"))
 $(eval $(call gb_AutoInstall_add_module,ooo,LIBO_LIB_FILE,LIBO_EXECUTABLE,LIBO_JAR_FILE))
diff --git a/scp2/InstallModule_math.mk b/scp2/InstallModule_math.mk
index e498f93..3b2d33f 100644
--- a/scp2/InstallModule_math.mk
+++ b/scp2/InstallModule_math.mk
@@ -9,7 +9,10 @@
 
 $(eval $(call gb_InstallModule_InstallModule,scp2/math))
 
-$(eval $(call gb_InstallModule_use_auto_install_libs,scp2/math,math))
+$(eval $(call gb_InstallModule_use_auto_install_libs,scp2/math,\
+	math \
+	math_brand \
+))
 
 $(eval $(call gb_InstallModule_define_if_set,scp2/math,\
 	ENABLE_MACOSX_SANDBOX \
diff --git a/scp2/source/math/file_math.scp b/scp2/source/math/file_math.scp
index 9b57ea7..6fab35a 100644
--- a/scp2/source/math/file_math.scp
+++ b/scp2/source/math/file_math.scp
@@ -35,11 +35,11 @@ File gid_File_Help_Smath_Zip
 End
 #endif
 
-#ifndef MACOSX
+#if !defined MACOSX && !defined WNT
 File gid_File_Exe_Smath
     BIN_FILE_BODY;
     Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(smath);
+    Name = "smath";
     Styles = (PACKED);
 End
 #endif
diff --git a/scp2/source/math/folderitem_math.scp b/scp2/source/math/folderitem_math.scp
index fb8bbcd..44ddc07 100644
--- a/scp2/source/math/folderitem_math.scp
+++ b/scp2/source/math/folderitem_math.scp
@@ -23,8 +23,8 @@ FolderItem gid_Folderitem_Smath
     Name = "%PRODUCTNAME Math";
     ModuleID = gid_Module_Prg_Math_Bin;
     FolderID = gid_Folder_Staroffice51;
-    FileID = gid_File_Exe_Smath;
-    IconFile = gid_File_Exe_Smath;
+    FileID = auto_math_brand_exe_smath;
+    IconFile = auto_math_brand_exe_smath;
     IconID = 0;
     WkDir = gid_Brand_Dir_Program;
     Parameter = "";
diff --git a/scp2/source/math/module_math.scp b/scp2/source/math/module_math.scp
index d433178..c281437 100644
--- a/scp2/source/math/module_math.scp
+++ b/scp2/source/math/module_math.scp
@@ -19,6 +19,7 @@
 #include "macros.inc"
 
 #include "AutoInstall/math"
+#include "AutoInstall/math_brand"
 
 Module gid_Module_Prg_Math
     MOD_NAME_DESC ( MODULE_PRG_MATH );
@@ -51,7 +52,7 @@ Module gid_Module_Brand_Prg_Math
     Minimal = YES;
     Default = YES;
     Styles = (HIDDEN_ROOT);
-    Files = (gid_File_Exe_Smath);
+    Files = (auto_math_brand_ALL,gid_File_Exe_Smath);
 End
 
 Module gid_Module_Langpack_Math_Template
commit 3ba20ef5ff0bce21da706815e8dca911b24b688b
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 23:57:21 2014 +0100

    scp2: move impress executables to AutoInstall
    
    Change-Id: I312a9921e8760ee93282ef0706469fdea3fabea9

diff --git a/Repository.mk b/Repository.mk
index 0125aa4..182652c 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -116,6 +116,12 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,draw_brand, \
 	) \
 ))
 
+$(eval $(call gb_Helper_register_executables_for_install,OOO,impress_brand, \
+	$(if $(filter WNT,$(OS)), \
+		simpress \
+	) \
+))
+
 $(eval $(call gb_Helper_register_executables_for_install,OOO,ooo, \
 	gengal \
 ))
@@ -159,7 +165,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(filter WNT,$(OS)), \
 		quickstart \
 		senddoc \
-		simpress \
 		smath \
 		sweb \
 		swriter \
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index 1bad46f..23d56a0 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -24,6 +24,7 @@ $(eval $(call gb_AutoInstall_add_module,extensions_rhino,,,LIBO_JAR_FILE))
 $(eval $(call gb_AutoInstall_add_module,gnome,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,graphicfilter,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,impress,LIBO_LIB_FILE))
+$(eval $(call gb_AutoInstall_add_module,impress_brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,kde,LIBO_LIB_FILE,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,math,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,ogltrans,LIBO_LIB_FILE))
diff --git a/scp2/InstallModule_impress.mk b/scp2/InstallModule_impress.mk
index 95b4965..0f10c9d 100644
--- a/scp2/InstallModule_impress.mk
+++ b/scp2/InstallModule_impress.mk
@@ -11,6 +11,7 @@ $(eval $(call gb_InstallModule_InstallModule,scp2/impress))
 
 $(eval $(call gb_InstallModule_use_auto_install_libs,scp2/impress,\
 	impress \
+	impress_brand \
 	ogltrans \
 ))
 
diff --git a/scp2/source/impress/file_impress.scp b/scp2/source/impress/file_impress.scp
index 7cf3eb5..5cb4126 100644
--- a/scp2/source/impress/file_impress.scp
+++ b/scp2/source/impress/file_impress.scp
@@ -33,11 +33,11 @@ File gid_File_Help_Simpress_Zip
 End
 #endif
 
-#ifndef MACOSX
+#if !defined MACOSX && !defined WNT
 File gid_File_Exe_Simpress
     BIN_FILE_BODY;
     Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(simpress);
+    Name = "simpress";
     Styles = (PACKED);
 End
 #endif
diff --git a/scp2/source/impress/folderitem_impress.scp b/scp2/source/impress/folderitem_impress.scp
index 44adbbe..c35221b 100644
--- a/scp2/source/impress/folderitem_impress.scp
+++ b/scp2/source/impress/folderitem_impress.scp
@@ -23,8 +23,8 @@ FolderItem gid_Folderitem_Simpress
     Name = "%PRODUCTNAME Impress";
     ModuleID = gid_Module_Prg_Impress_Bin;
     FolderID = gid_Folder_Staroffice51;
-    FileID = gid_File_Exe_Simpress;
-    IconFile = gid_File_Exe_Simpress;
+    FileID = auto_impress_brand_exe_simpress;
+    IconFile = auto_impress_brand_exe_simpress;
     IconID = 0;
     WkDir = gid_Brand_Dir_Program;
     Parameter = "";
diff --git a/scp2/source/impress/module_impress.scp b/scp2/source/impress/module_impress.scp
index dd2eeba..38e445f 100644
--- a/scp2/source/impress/module_impress.scp
+++ b/scp2/source/impress/module_impress.scp
@@ -19,6 +19,7 @@
 #include "macros.inc"
 
 #include "AutoInstall/impress"
+#include "AutoInstall/impress_brand"
 
 Module gid_Module_Prg_Impress
     MOD_NAME_DESC ( MODULE_PRG_IMPRESS );
@@ -52,7 +53,7 @@ Module gid_Module_Brand_Prg_Impress
     Minimal = YES;
     Default = YES;
     Styles = (HIDDEN_ROOT);
-    Files = (gid_File_Exe_Simpress);
+    Files = (auto_impress_brand_ALL,gid_File_Exe_Simpress);
 End
 
 Module gid_Module_Langpack_Impress_Template
commit 557f58d1cfac2d602c3cc74927eea9e771fe5d67
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 23:51:16 2014 +0100

    scp2: move draw executables to AutoInstall
    
    Change-Id: I6f7642a39fb72cfed85638cdd9015bf0aced8a20

diff --git a/Repository.mk b/Repository.mk
index 8f3e005..0125aa4 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -110,6 +110,12 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,calc_brand, \
 	) \
 ))
 
+$(eval $(call gb_Helper_register_executables_for_install,OOO,draw_brand, \
+	$(if $(filter WNT,$(OS)), \
+		sdraw \
+	) \
+))
+
 $(eval $(call gb_Helper_register_executables_for_install,OOO,ooo, \
 	gengal \
 ))
@@ -152,7 +158,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(and $(ENABLE_GTK), $(filter LINUX,$(OS))), gtktiledviewer) \
 	$(if $(filter WNT,$(OS)), \
 		quickstart \
-		sdraw \
 		senddoc \
 		simpress \
 		smath \
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index eaa1666..1bad46f 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -18,6 +18,7 @@ $(eval $(call gb_AutoInstall_add_module,brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,calc,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,calc_brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,crashrep,,LIBO_EXECUTABLE))
+$(eval $(call gb_AutoInstall_add_module,draw_brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,extensions_bsh,,,LIBO_JAR_FILE))
 $(eval $(call gb_AutoInstall_add_module,extensions_rhino,,,LIBO_JAR_FILE))
 $(eval $(call gb_AutoInstall_add_module,gnome,LIBO_LIB_FILE))
diff --git a/scp2/InstallModule_draw.mk b/scp2/InstallModule_draw.mk
index 0ec9c4f..a7c02be 100644
--- a/scp2/InstallModule_draw.mk
+++ b/scp2/InstallModule_draw.mk
@@ -9,6 +9,10 @@
 
 $(eval $(call gb_InstallModule_InstallModule,scp2/draw))
 
+$(eval $(call gb_InstallModule_use_auto_install_libs,scp2/draw,\
+	draw_brand \
+))
+
 $(eval $(call gb_InstallModule_define_if_set,scp2/draw,\
 	ENABLE_MACOSX_SANDBOX \
 ))
diff --git a/scp2/source/draw/file_draw.scp b/scp2/source/draw/file_draw.scp
index 74285e0..4f8d610 100644
--- a/scp2/source/draw/file_draw.scp
+++ b/scp2/source/draw/file_draw.scp
@@ -33,11 +33,11 @@ File gid_File_Help_Sdraw_Zip
 End
 #endif
 
-#ifndef MACOSX
+#if !defined MACOSX && !defined WNT
 File gid_File_Exe_Sdraw
     BIN_FILE_BODY;
     Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(sdraw);
+    Name = "sdraw";
     Styles = (PACKED);
 End
 #endif
diff --git a/scp2/source/draw/folderitem_draw.scp b/scp2/source/draw/folderitem_draw.scp
index f692707..5dc8757 100644
--- a/scp2/source/draw/folderitem_draw.scp
+++ b/scp2/source/draw/folderitem_draw.scp
@@ -23,8 +23,8 @@ FolderItem gid_Folderitem_Sdraw
     Name = "%PRODUCTNAME Draw";
     ModuleID = gid_Module_Prg_Draw_Bin;
     FolderID = gid_Folder_Staroffice51;
-    FileID = gid_File_Exe_Sdraw;
-    IconFile = gid_File_Exe_Sdraw;
+    FileID = auto_draw_brand_exe_sdraw;
+    IconFile = auto_draw_brand_exe_sdraw;
     IconID = 0;
     WkDir = gid_Brand_Dir_Program;
     Parameter = "";
diff --git a/scp2/source/draw/module_draw.scp b/scp2/source/draw/module_draw.scp
index c0dc581..a2db15d 100644
--- a/scp2/source/draw/module_draw.scp
+++ b/scp2/source/draw/module_draw.scp
@@ -18,6 +18,8 @@
 
 #include "macros.inc"
 
+#include "AutoInstall/draw_brand"
+
 Module gid_Module_Prg_Draw
     MOD_NAME_DESC ( MODULE_PRG_DRAW );
     ParentID = gid_Module_Prg;
@@ -48,7 +50,7 @@ Module gid_Module_Brand_Prg_Draw
     Minimal = YES;
     Default = YES;
     Styles = (HIDDEN_ROOT);
-    Files = (gid_File_Exe_Sdraw);
+    Files = (auto_draw_brand_ALL,gid_File_Exe_Sdraw);
 End
 
 Module gid_Module_Langpack_Draw_Template
commit 5ceb8b7be6102d2f2b8228afc8c17d9e0d380be2
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 23:42:05 2014 +0100

    scp2: move calc executables to AutoInstall
    
    Change-Id: Id69718fbdf429a4e9196e8b9c5c8a71171ad0847

diff --git a/Repository.mk b/Repository.mk
index 9940f05..8f3e005 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -104,6 +104,12 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,base, \
 	) \
 ))
 
+$(eval $(call gb_Helper_register_executables_for_install,OOO,calc_brand, \
+	$(if $(filter WNT,$(OS)), \
+		scalc \
+	) \
+))
+
 $(eval $(call gb_Helper_register_executables_for_install,OOO,ooo, \
 	gengal \
 ))
@@ -146,7 +152,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(and $(ENABLE_GTK), $(filter LINUX,$(OS))), gtktiledviewer) \
 	$(if $(filter WNT,$(OS)), \
 		quickstart \
-		scalc \
 		sdraw \
 		senddoc \
 		simpress \
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index f476032..eaa1666 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -16,6 +16,7 @@ $(eval $(call gb_AutoInstall_add_module,base,LIBO_LIB_FILE,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,base_brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,calc,LIBO_LIB_FILE))
+$(eval $(call gb_AutoInstall_add_module,calc_brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,crashrep,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,extensions_bsh,,,LIBO_JAR_FILE))
 $(eval $(call gb_AutoInstall_add_module,extensions_rhino,,,LIBO_JAR_FILE))
diff --git a/scp2/InstallModule_calc.mk b/scp2/InstallModule_calc.mk
index 1aff01c..0484fac 100644
--- a/scp2/InstallModule_calc.mk
+++ b/scp2/InstallModule_calc.mk
@@ -9,7 +9,10 @@
 
 $(eval $(call gb_InstallModule_InstallModule,scp2/calc))
 
-$(eval $(call gb_InstallModule_use_auto_install_libs,scp2/calc,calc))
+$(eval $(call gb_InstallModule_use_auto_install_libs,scp2/calc,\
+	calc \
+	calc_brand \
+))
 
 $(eval $(call gb_InstallModule_define_if_set,scp2/calc,\
 	ENABLE_MACOSX_SANDBOX \
diff --git a/scp2/source/calc/file_calc.scp b/scp2/source/calc/file_calc.scp
index c3d2ed2..390fd0e 100644
--- a/scp2/source/calc/file_calc.scp
+++ b/scp2/source/calc/file_calc.scp
@@ -41,11 +41,11 @@ File gid_File_Help_Scalc_Zip
 End
 #endif
 
-#ifndef MACOSX
+#if !defined MACOSX && !defined WNT
 File gid_File_Exe_Scalc
     BIN_FILE_BODY;
     Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(scalc);
+    Name = "scalc";
     Styles = (PACKED);
 End
 #endif
diff --git a/scp2/source/calc/folderitem_calc.scp b/scp2/source/calc/folderitem_calc.scp
index 05db68f..a41ade6 100644
--- a/scp2/source/calc/folderitem_calc.scp
+++ b/scp2/source/calc/folderitem_calc.scp
@@ -23,8 +23,8 @@ FolderItem gid_Folderitem_Scalc
     Name = "%PRODUCTNAME Calc";
     ModuleID = gid_Module_Prg_Calc_Bin;
     FolderID = gid_Folder_Staroffice51;
-    FileID = gid_File_Exe_Scalc;
-    IconFile = gid_File_Exe_Scalc;
+    FileID = auto_calc_brand_exe_scalc;
+    IconFile = auto_calc_brand_exe_scalc;
     IconID = 0;
     WkDir = gid_Brand_Dir_Program;
     Parameter = "";
diff --git a/scp2/source/calc/module_calc.scp b/scp2/source/calc/module_calc.scp
index 020af52..47d6426 100644
--- a/scp2/source/calc/module_calc.scp
+++ b/scp2/source/calc/module_calc.scp
@@ -19,6 +19,7 @@
 #include "macros.inc"
 
 #include "AutoInstall/calc"
+#include "AutoInstall/calc_brand"
 
 Module gid_Module_Prg_Calc
     MOD_NAME_DESC ( MODULE_PRG_CALC );
@@ -59,7 +60,7 @@ Module gid_Module_Brand_Prg_Calc
     Minimal = YES;
     Default = YES;
     Styles = (HIDDEN_ROOT);
-    Files = (gid_File_Exe_Scalc);
+    Files = (auto_calc_brand_ALL,gid_File_Exe_Scalc);
 End
 
 Module gid_Module_Langpack_Calc_Template
commit ee80cbb7122714d05b1b939e8276138517f9ece5
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 23:35:21 2014 +0100

    scp2: move base executables to AutoInstall
    
    Change-Id: I772bbfc05d4f8fd38df7a75d3b0982c843be2524

diff --git a/Repository.mk b/Repository.mk
index f3e4314..9940f05 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -92,6 +92,18 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,brand, \
 	) \
 ))
 
+$(eval $(call gb_Helper_register_executables_for_install,OOO,base_brand, \
+	$(if $(filter WNT,$(OS)), \
+		sbase \
+	) \
+))
+
+$(eval $(call gb_Helper_register_executables_for_install,OOO,base, \
+	$(if $(filter WNT,$(OS)), \
+		odbcconfig \
+	) \
+))
+
 $(eval $(call gb_Helper_register_executables_for_install,OOO,ooo, \
 	gengal \
 ))
@@ -133,9 +145,7 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	tiledrendering \
 	$(if $(and $(ENABLE_GTK), $(filter LINUX,$(OS))), gtktiledviewer) \
 	$(if $(filter WNT,$(OS)), \
-		odbcconfig \
 		quickstart \
-		sbase \
 		scalc \
 		sdraw \
 		senddoc \
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index 588df01..f476032 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -12,7 +12,8 @@ $(eval $(call gb_AutoInstall_AutoInstall))
 $(eval $(call gb_AutoInstall_add_module,activexbinarytable,LIBO_LIB_FILE_BINARYTABLE))
 $(eval $(call gb_AutoInstall_add_module,activex,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,activexwin64,LIBO_LIB_FILE_COMPONENTCONDITION,,,"VersionNT64"))
-$(eval $(call gb_AutoInstall_add_module,base,LIBO_LIB_FILE))
+$(eval $(call gb_AutoInstall_add_module,base,LIBO_LIB_FILE,LIBO_EXECUTABLE))
+$(eval $(call gb_AutoInstall_add_module,base_brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,calc,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,crashrep,,LIBO_EXECUTABLE))
diff --git a/scp2/InstallModule_base.mk b/scp2/InstallModule_base.mk
index 8052410..2efba18 100644
--- a/scp2/InstallModule_base.mk
+++ b/scp2/InstallModule_base.mk
@@ -11,6 +11,7 @@ $(eval $(call gb_InstallModule_InstallModule,scp2/base))
 
 $(eval $(call gb_InstallModule_use_auto_install_libs,scp2/base,\
 	base \
+	base_brand \
 	postgresqlsdbc \
 ))
 
diff --git a/scp2/source/base/file_base.scp b/scp2/source/base/file_base.scp
index 4aec6bb..d1af15a 100644
--- a/scp2/source/base/file_base.scp
+++ b/scp2/source/base/file_base.scp
@@ -18,20 +18,11 @@
 
 #include "macros.inc"
 
-#ifndef MACOSX
+#if !defined MACOSX && !defined WNT
 File gid_File_Exe_Sbase
     BIN_FILE_BODY;
     Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(sbase);
-    Styles = (PACKED);
-End
-#endif
-
-#if defined WNT
-File gid_File_Exe_Odbcconfig
-    BIN_FILE_BODY;
-    Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(odbcconfig);
+    Name = "sbase";
     Styles = (PACKED);
 End
 #endif
diff --git a/scp2/source/base/folderitem_base.scp b/scp2/source/base/folderitem_base.scp
index 51a940b..75e1d5d 100644
--- a/scp2/source/base/folderitem_base.scp
+++ b/scp2/source/base/folderitem_base.scp
@@ -23,8 +23,8 @@ FolderItem gid_Folderitem_Sbase
     Name = "%PRODUCTNAME Base";
     ModuleID = gid_Module_Prg_Base_Bin;
     FolderID = gid_Folder_Staroffice51;
-    FileID = gid_File_Exe_Sbase;
-    IconFile = gid_File_Exe_Sbase;
+    FileID = auto_base_brand_exe_sbase;
+    IconFile = auto_base_brand_exe_sbase;
     IconID = 0;
     WkDir = gid_Brand_Dir_Program;
     Parameter = "";
diff --git a/scp2/source/base/module_base.scp b/scp2/source/base/module_base.scp
index 7a46408..c593e7e 100644
--- a/scp2/source/base/module_base.scp
+++ b/scp2/source/base/module_base.scp
@@ -19,6 +19,7 @@
 #include "macros.inc"
 
 #include "AutoInstall/base"
+#include "AutoInstall/base_brand"
 
 Module gid_Module_Prg_Base
     MOD_NAME_DESC(MODULE_PRG_BASE);
@@ -50,7 +51,7 @@ Module gid_Module_Brand_Prg_Base
     Minimal = YES;
     Default = YES;
     Styles = (HIDDEN_ROOT);
-    Files = (gid_File_Exe_Sbase);
+    Files = (auto_base_brand_ALL,gid_File_Exe_Sbase);
 End
 
 Module gid_Module_Langpack_Base_Template
commit f3616065a72656a11a75d7f5dae363050b03daed
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 23:03:56 2014 +0100

    installer: let's make missing FileID a fatal error
    
    ... because the upcoming AutoInstall conversions introduce dependency
    from FolderItem to auto-installed executables, and we want to ensure
    that that keeps working.
    
    Change-Id: I08d4aeddd28b93f080e201716597315e9a6ec2d6

diff --git a/Repository.mk b/Repository.mk
index f7f29a6..f3e4314 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -85,6 +85,7 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,brand, \
 	soffice_bin \
 	$(if $(filter DESKTOP,$(BUILD_TYPE)),unopkg_bin) \
 	$(if $(filter WNT,$(OS)), \
+		soffice \
 		unoinfo \
 		unopkg \
 		unopkg_com \
@@ -139,7 +140,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 		sdraw \
 		senddoc \
 		simpress \
-		soffice \
 		smath \
 		sweb \
 		swriter \
diff --git a/scp2/source/ooo/common_brand.scp b/scp2/source/ooo/common_brand.scp
index 314dd87..01c072d 100644
--- a/scp2/source/ooo/common_brand.scp
+++ b/scp2/source/ooo/common_brand.scp
@@ -505,16 +505,6 @@ End
 #endif
 
 #ifdef WNT
-// TODO: some FolderItem reference this?
-File gid_Brand_File_Bin_Soffice
-    BIN_FILE_BODY;
-    Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(soffice);
-    Styles = (PACKED);
-End
-#endif
-
-#ifdef WNT
 File gid_Brand_File_Desktophelper_Txt
     TXT_FILE_BODY;
     Styles = (PACKED);
diff --git a/scp2/source/ooo/folderitem_ooo.scp b/scp2/source/ooo/folderitem_ooo.scp
index ecfc7f2..ff8a371 100644
--- a/scp2/source/ooo/folderitem_ooo.scp
+++ b/scp2/source/ooo/folderitem_ooo.scp
@@ -26,8 +26,8 @@ FolderItem gid_Folderitem_LibreOffice
 #else
     FolderID = gid_Folder_Staroffice51;
 #endif
-    FileID = gid_Brand_File_Bin_Soffice;
-    IconFile = gid_Brand_File_Bin_Soffice;
+    FileID = auto_brand_exe_soffice;
+    IconFile = auto_brand_exe_soffice;
     IconID = 0;
     WkDir = gid_Brand_Dir_Program;
     Parameter = "";
@@ -49,8 +49,8 @@ FolderItem gid_Folderitem_Soffice_Desktop
 #endif
     ModuleID = gid_Module_Root;
     FolderID = PREDEFINED_DESKTOP;
-    FileID = gid_Brand_File_Bin_Soffice;
-    IconFile = gid_Brand_File_Bin_Soffice;
+    FileID = auto_brand_exe_soffice;
+    IconFile = auto_brand_exe_soffice;
     IconID = 0;
     ComponentIDFile = "gid_Brand_File_Desktophelper_Txt";
     WkDir = gid_Brand_Dir_Program;
diff --git a/solenv/bin/modules/installer/setupscript.pm b/solenv/bin/modules/installer/setupscript.pm
index 9cf5e92..6eefe01 100644
--- a/solenv/bin/modules/installer/setupscript.pm
+++ b/solenv/bin/modules/installer/setupscript.pm
@@ -418,9 +418,10 @@ sub prepare_non_advertised_files
             if ( $folderitem->{'ComponentIDFile'} ) { $fileid = $folderitem->{'ComponentIDFile'}; }
             my $onefile = installer::worker::find_file_by_id($filesref, $fileid);
 
-            # Attention: If $onefile with "FileID" is not found, this is not always an error.
-            # FileID can also contain an executable file, for example msiexec.exe.
             if ( $onefile ne "" ) { $onefile->{'needs_user_registry_key'} = 1; }
+            else {
+                installer::exiter::exit_program("ERROR: Did not find FileID $fileid in file collection", "prepare_non_advertised_files");
+            }
         }
     }
 }
commit 368729decbf368161b0fed3be262c2bad840b6f6
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 22:40:39 2014 +0100

    scp2: move python executables to AutoInstall
    
    Change-Id: I94919f11150f39148219afc613ced99f74c539c0

diff --git a/Repository.mk b/Repository.mk
index b624d92..f7f29a6 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -102,6 +102,12 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,crashrep, \
 ))
 endif
 
+$(eval $(call gb_Helper_register_executables_for_install,OOO,python, \
+	$(if $(filter WNT,$(OS)), \
+		python \
+	) \
+))
+
 ifneq ($(ENABLE_PDFIMPORT),)
 $(eval $(call gb_Helper_register_executables_for_install,OOO,pdfimport, \
 	xpdfimport \
@@ -127,7 +133,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(and $(ENABLE_GTK), $(filter LINUX,$(OS))), gtktiledviewer) \
 	$(if $(filter WNT,$(OS)), \
 		odbcconfig \
-		python \
 		quickstart \
 		sbase \
 		scalc \
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index 1e492e1..588df01 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -27,7 +27,7 @@ $(eval $(call gb_AutoInstall_add_module,ogltrans,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,onlineupdate,LIBO_LIB_FILE_COMPONENTCONDITION,,,"ISCHECKFORPRODUCTUPDATES=1"))
 $(eval $(call gb_AutoInstall_add_module,ooo,LIBO_LIB_FILE,LIBO_EXECUTABLE,LIBO_JAR_FILE))
 $(eval $(call gb_AutoInstall_add_module,ooobinarytable,LIBO_LIB_FILE_BINARYTABLE))
-$(eval $(call gb_AutoInstall_add_module,python,LIBO_LIB_FILE))
+$(eval $(call gb_AutoInstall_add_module,python,LIBO_LIB_FILE,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,postgresqlsdbc,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,pdfimport,LIBO_LIB_FILE,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,reportbuilder,LIBO_LIB_FILE,,LIBO_JAR_FILE))
diff --git a/scp2/source/python/file_python.scp b/scp2/source/python/file_python.scp
index 247748a..e5bebef 100644
--- a/scp2/source/python/file_python.scp
+++ b/scp2/source/python/file_python.scp
@@ -43,18 +43,12 @@ End
 
 #ifndef SYSTEM_PYTHON
 
-#if !defined MACOSX
+#if !defined MACOSX && !defined WNT
 File gid_File_Py_Bin_Python
     BIN_FILE_BODY;
-#ifdef WNT
-    Name = EXENAME(python);
-    Dir = gid_Brand_Dir_Program;
-    Styles = (PACKED);
-#else
     Name = "python_shell.filelist";
     Dir = FILELIST_DIR;
     Styles = (FILELIST, PACKED);
-#endif
 End
 #endif
 
@@ -102,7 +96,7 @@ End
 // python_wrapper.exe
 File gid_File_Py_Bin_Python
     BIN_FILE_BODY;
-    Name = EXENAME(python);
+    Name = "python.exe";
     Dir = gid_Brand_Dir_Program;
     Styles = (PACKED);
 End
@@ -132,7 +126,7 @@ End
 File gid_File_Py_Python_Bin
     BIN_FILE_BODY;
     Dir = gid_Dir_Py_PythonCore_Bin;
-    Name = EXENAME(python);
+    Name = "python.exe";
     Styles = (PACKED);
 End
 
commit f4fac5eed2b17782f0255127e837cb2f07253d92
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 22:32:40 2014 +0100

    scp2: move xpdfimport executables to AutoInstall
    
    Change-Id: I9b75436a03c06252530bbd54a7011fb553ceb9be

diff --git a/Repository.mk b/Repository.mk
index bf32244..b624d92 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -102,6 +102,12 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,crashrep, \
 ))
 endif
 
+ifneq ($(ENABLE_PDFIMPORT),)
+$(eval $(call gb_Helper_register_executables_for_install,OOO,pdfimport, \
+	xpdfimport \
+))
+endif
+
 $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(and $(ENABLE_GTK), $(filter LINUX,$(OS))), tilebench) \
 	gnome-open-url.bin \
@@ -119,7 +125,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	vcldemo \
 	tiledrendering \
 	$(if $(and $(ENABLE_GTK), $(filter LINUX,$(OS))), gtktiledviewer) \
-	xpdfimport \
 	$(if $(filter WNT,$(OS)), \
 		odbcconfig \
 		python \
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index 78879ce..1e492e1 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -29,7 +29,7 @@ $(eval $(call gb_AutoInstall_add_module,ooo,LIBO_LIB_FILE,LIBO_EXECUTABLE,LIBO_J
 $(eval $(call gb_AutoInstall_add_module,ooobinarytable,LIBO_LIB_FILE_BINARYTABLE))
 $(eval $(call gb_AutoInstall_add_module,python,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,postgresqlsdbc,LIBO_LIB_FILE))
-$(eval $(call gb_AutoInstall_add_module,pdfimport,LIBO_LIB_FILE))
+$(eval $(call gb_AutoInstall_add_module,pdfimport,LIBO_LIB_FILE,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,reportbuilder,LIBO_LIB_FILE,,LIBO_JAR_FILE))
 $(eval $(call gb_AutoInstall_add_module,sdk,,SDK_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,tde,LIBO_LIB_FILE))
diff --git a/scp2/source/ooo/module_pdfimport.scp b/scp2/source/ooo/module_pdfimport.scp
index 320ba85..3c6add5 100644
--- a/scp2/source/ooo/module_pdfimport.scp
+++ b/scp2/source/ooo/module_pdfimport.scp
@@ -36,7 +36,6 @@ Module gid_Module_Pdfimport
     Dirs = (gid_Dir_Share_Xpdfimport);
     Files = (auto_pdfimport_ALL,
         gid_File_Dat_XpdfimportErrPdf,
-        gid_File_Exe_Xpdfimport,
         gid_File_Xcd_Pdfimport);
 End
 
@@ -52,13 +51,6 @@ File gid_File_Dat_XpdfimportErrPdf
     Styles = (PACKED);
 End
 
-File gid_File_Exe_Xpdfimport
-    BIN_FILE_BODY;
-    Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(xpdfimport);
-    Styles = (PACKED);
-End
-
 File gid_File_Xcd_Pdfimport
     TXT_FILE_BODY;
     Dir = gid_Brand_Dir_Share_Registry;
commit 7c898c933cb5c4baa7315bb5547a1b53cb12ea61
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 22:11:00 2014 +0100

    scp2: move brand executables to AutoInstall
    
    ... except for soffice.exe which is referenced by some FolderItem.
    
    Change-Id: Ie5788aa950f0b8526220fb2c8b9281ce934b8a5d

diff --git a/Repository.mk b/Repository.mk
index 551a95c..bf32244 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -80,6 +80,17 @@ $(eval $(call gb_Helper_register_executables_for_install,SDK,sdk, \
 	$(if $(filter ODK,$(BUILD_TYPE)),uno-skeletonmaker) \
 ))
 
+$(eval $(call gb_Helper_register_executables_for_install,OOO,brand, \
+	$(if $(filter-out ANDROID IOS MACOSX WNT,$(OS)),oosplash) \
+	soffice_bin \
+	$(if $(filter DESKTOP,$(BUILD_TYPE)),unopkg_bin) \
+	$(if $(filter WNT,$(OS)), \
+		unoinfo \
+		unopkg \
+		unopkg_com \
+	) \
+))
+
 $(eval $(call gb_Helper_register_executables_for_install,OOO,ooo, \
 	gengal \
 ))
@@ -94,9 +105,7 @@ endif
 $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(and $(ENABLE_GTK), $(filter LINUX,$(OS))), tilebench) \
 	gnome-open-url.bin \
-	$(if $(filter-out ANDROID IOS MACOSX WNT,$(OS)),oosplash) \
 	$(if $(ENABLE_NPAPI_FROM_BROWSER),pluginapp.bin) \
-	soffice_bin \
 	$(if $(filter $(GUIBASE)$(ENABLE_GTK),unxTRUE), \
 		xid-fullscreen-on-all-monitors \
 	) \
@@ -110,7 +119,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	vcldemo \
 	tiledrendering \
 	$(if $(and $(ENABLE_GTK), $(filter LINUX,$(OS))), gtktiledviewer) \
-	$(if $(filter DESKTOP,$(BUILD_TYPE)),unopkg_bin) \
 	xpdfimport \
 	$(if $(filter WNT,$(OS)), \
 		odbcconfig \
@@ -125,9 +133,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 		smath \
 		sweb \
 		swriter \
-		unoinfo \
-		unopkg \
-		unopkg_com \
 	) \
 ))
 
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index 1a61765..78879ce 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -13,6 +13,7 @@ $(eval $(call gb_AutoInstall_add_module,activexbinarytable,LIBO_LIB_FILE_BINARYT
 $(eval $(call gb_AutoInstall_add_module,activex,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,activexwin64,LIBO_LIB_FILE_COMPONENTCONDITION,,,"VersionNT64"))
 $(eval $(call gb_AutoInstall_add_module,base,LIBO_LIB_FILE))
+$(eval $(call gb_AutoInstall_add_module,brand,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,calc,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,crashrep,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,extensions_bsh,,,LIBO_JAR_FILE))
diff --git a/scp2/InstallModule_ooo.mk b/scp2/InstallModule_ooo.mk
index df767a1..d2ef3f5 100644
--- a/scp2/InstallModule_ooo.mk
+++ b/scp2/InstallModule_ooo.mk
@@ -10,6 +10,7 @@
 $(eval $(call gb_InstallModule_InstallModule,scp2/ooo))
 
 $(eval $(call gb_InstallModule_use_auto_install_libs,scp2/ooo,\
+	brand \
 	ooo \
 	ooobinarytable \
 	reportbuilder \
diff --git a/scp2/source/ooo/common_brand.scp b/scp2/source/ooo/common_brand.scp
index ce5dcbc..314dd87 100644
--- a/scp2/source/ooo/common_brand.scp
+++ b/scp2/source/ooo/common_brand.scp
@@ -27,6 +27,7 @@
 
 #include "macros.inc"
 
+#include "AutoInstall/brand"
 #include "AutoInstall/crashrep"
 
 #include "config_folders.h"
@@ -54,15 +55,12 @@ Module gid_Module_Root_Brand
             gid_Brand_Dir_Share_Registry,
             gid_Brand_Dir_Share_Xdg);
     Files = (auto_crashrep_ALL,
+             auto_brand_ALL,
              gid_Brand_File_Bin_Crashreport_Script,
              gid_Brand_File_Gdb_Trace,
              gid_Brand_File_Bin_Soffice,
-             gid_Brand_File_Bin_Soffice_Bin,
              gid_Brand_File_Bin_Soffice_Bin_Manifest,
              gid_Brand_File_Bin_Unoinfo,
-             gid_Brand_File_Bin_Unopkgcom,
-             gid_Brand_File_Bin_Unopkgexe,
-             gid_Brand_File_Bin_Unopkg,
              gid_Brand_File_Bmp_IntroAboutShell,
              gid_Brand_File_Bmp_IntroAboutShell_custom,
 	     gid_Brand_File_Desktophelper_Txt,
@@ -504,35 +502,16 @@ File gid_Brand_File_Bin_Soffice
     Styles = (FILELIST, PACKED);
 End
 
-#else
+#endif
 
+#ifdef WNT
+// TODO: some FolderItem reference this?
 File gid_Brand_File_Bin_Soffice
     BIN_FILE_BODY;
     Dir = gid_Brand_Dir_Program;
     Name = EXENAME(soffice);
     Styles = (PACKED);
 End
-
-#endif
-
-#ifndef MACOSX
-File gid_Brand_File_Bin_Soffice_Bin
-    BIN_FILE_BODY;
-    Dir = gid_Brand_Dir_Program;
-    Styles = (PACKED);
-    Name = "soffice.bin";
-End
-#endif
-
-#if defined UNX && ! defined MACOSX
-
-File gid_File_Bin_QStart_Bin
-    BIN_FILE_BODY;
-    Dir = gid_Brand_Dir_Program;
-    Styles = (PACKED);
-    Name = "oosplash";
-End
-
 #endif
 
 #ifdef WNT
@@ -545,30 +524,12 @@ File gid_Brand_File_Desktophelper_Txt
 End
 #endif
 
-#if !defined MACOSX
+#if !defined MACOSX && !defined WNT
 File gid_Brand_File_Bin_Unoinfo
     BIN_FILE_BODY;
     Dir = gid_Brand_Dir_Program;
-    Name = EXENAME(unoinfo);
-    Styles = (PACKED);
-End
-#endif
-
-#ifdef WNT
-File gid_Brand_File_Bin_Unopkgcom
-    BIN_FILE_BODY;
-    Dir = gid_Brand_Dir_Program;
-    Styles = (PACKED);
-    Name = "unopkg.com";
-End
-#endif
-
-#ifdef WNT
-File gid_Brand_File_Bin_Unopkgexe
-    BIN_FILE_BODY;
-    Dir = gid_Brand_Dir_Program;
+    Name = "unoinfo";
     Styles = (PACKED);
-    Name = "unopkg.exe";
 End
 #endif
 
@@ -581,13 +542,6 @@ File gid_Brand_File_Script_Unopkg
 End
 #endif
 
-File gid_Brand_File_Bin_Unopkg
-    BIN_FILE_BODY;
-    Dir = gid_Brand_Dir_Program;
-    Styles = (PACKED);
-    Name = "unopkg.bin";
-End
-
 File gid_Brand_File_Bmp_IntroAboutShell
     TXT_FILE_BODY;
     Dir = FILELIST_DIR;
commit 0183dc88e25b30725c118fd5b515e739d717b6be
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 21:36:11 2014 +0100

    scp2: move crashrep executables to AutoInstall
    
    Change-Id: Ib9fba534491ce67d329a375a359eef4520c0a3a1

diff --git a/Repository.mk b/Repository.mk
index 219db85..551a95c 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -84,9 +84,15 @@ $(eval $(call gb_Helper_register_executables_for_install,OOO,ooo, \
 	gengal \
 ))
 
+ifneq ($(ENABLE_CRASHDUMP),)
+$(eval $(call gb_Helper_register_executables_for_install,OOO,crashrep, \
+	crashrep \
+	$(if $(filter WNT,$(OS)),crashrep_com) \
+))
+endif
+
 $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(and $(ENABLE_GTK), $(filter LINUX,$(OS))), tilebench) \
-	$(call gb_Helper_optional,CRASHREP,crashrep) \
 	gnome-open-url.bin \
 	$(if $(filter-out ANDROID IOS MACOSX WNT,$(OS)),oosplash) \
 	$(if $(ENABLE_NPAPI_FROM_BROWSER),pluginapp.bin) \
@@ -107,7 +113,6 @@ $(eval $(call gb_Helper_register_executables,OOO, \
 	$(if $(filter DESKTOP,$(BUILD_TYPE)),unopkg_bin) \
 	xpdfimport \
 	$(if $(filter WNT,$(OS)), \
-		crashrep_com \
 		odbcconfig \
 		python \
 		quickstart \
diff --git a/scp2/AutoInstall.mk b/scp2/AutoInstall.mk
index 5c55a3e..1a61765 100644
--- a/scp2/AutoInstall.mk
+++ b/scp2/AutoInstall.mk
@@ -14,6 +14,7 @@ $(eval $(call gb_AutoInstall_add_module,activex,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,activexwin64,LIBO_LIB_FILE_COMPONENTCONDITION,,,"VersionNT64"))
 $(eval $(call gb_AutoInstall_add_module,base,LIBO_LIB_FILE))
 $(eval $(call gb_AutoInstall_add_module,calc,LIBO_LIB_FILE))
+$(eval $(call gb_AutoInstall_add_module,crashrep,,LIBO_EXECUTABLE))
 $(eval $(call gb_AutoInstall_add_module,extensions_bsh,,,LIBO_JAR_FILE))
 $(eval $(call gb_AutoInstall_add_module,extensions_rhino,,,LIBO_JAR_FILE))
 $(eval $(call gb_AutoInstall_add_module,gnome,LIBO_LIB_FILE))
diff --git a/scp2/InstallModule_crashrep.mk b/scp2/InstallModule_crashrep.mk
index f8d90c4..1a72e14 100644
--- a/scp2/InstallModule_crashrep.mk
+++ b/scp2/InstallModule_crashrep.mk
@@ -9,6 +9,10 @@
 
 $(eval $(call gb_InstallModule_InstallModule,scp2/crashrep))
 
+$(eval $(call gb_InstallModule_use_auto_install_libs,scp2/crashrep,\
+	crashrep \
+))
+
 $(eval $(call gb_InstallModule_add_scpfiles,scp2/crashrep,\
     scp2/source/crashrep/file_crashrep \
 ))
diff --git a/scp2/source/crashrep/file_crashrep.scp b/scp2/source/crashrep/file_crashrep.scp
index ef652481..e502146 100644
--- a/scp2/source/crashrep/file_crashrep.scp
+++ b/scp2/source/crashrep/file_crashrep.scp
@@ -20,24 +20,6 @@
 
 // crashreporter files
 
-File gid_Brand_File_Bin_Crashreport
-    BIN_FILE_BODY;
-    Name = EXENAME(crashrep);
-    Dir = gid_Brand_Dir_Program;
-    Styles = (PACKED);
-End
-
-#ifdef WNT
-
-File gid_Brand_File_Bin_Crashreport_Com
-    BIN_FILE_BODY;
-    Name = "crashrep.com";
-    Dir = gid_Brand_Dir_Program;
-    Styles = (PACKED);
-End
-
-#endif
-
 #ifdef WNT
 
 File gid_Brand_File_Lib_Dbghelp
diff --git a/scp2/source/ooo/common_brand.scp b/scp2/source/ooo/common_brand.scp
index 8c08811..ce5dcbc 100644
--- a/scp2/source/ooo/common_brand.scp
+++ b/scp2/source/ooo/common_brand.scp
@@ -27,6 +27,8 @@
 
 #include "macros.inc"
 
+#include "AutoInstall/crashrep"
+
 #include "config_folders.h"
 
 Module gid_Module_Root_Brand
@@ -51,9 +53,8 @@ Module gid_Module_Root_Brand
             gid_Brand_Dir_Share_Labels,
             gid_Brand_Dir_Share_Registry,
             gid_Brand_Dir_Share_Xdg);
-    Files = (gid_Brand_File_Bin_Crashreport,
+    Files = (auto_crashrep_ALL,
              gid_Brand_File_Bin_Crashreport_Script,
-             gid_Brand_File_Bin_Crashreport_Com,
              gid_Brand_File_Gdb_Trace,
              gid_Brand_File_Bin_Soffice,
              gid_Brand_File_Bin_Soffice_Bin,
commit f801b7f07d73d973c2a34662626a4a0e033fa6e6
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 13:36:31 2014 +0100

    sw: translate "Rekursiv"
    
    Change-Id: Ib40dcbda3b2b9c8c196303f3f0c49e0ab05e0404

diff --git a/sw/source/core/bastyp/swcache.cxx b/sw/source/core/bastyp/swcache.cxx
index 7b2d4e2..7c1c3e1 100644
--- a/sw/source/core/bastyp/swcache.cxx
+++ b/sw/source/core/bastyp/swcache.cxx
@@ -33,7 +33,7 @@ void SwCache::Check()
     sal_uInt16 nCnt = 0;
     bool bFirstFound = false;
     SwCacheObj *pObj = pRealFirst;
-    SwCacheObj *pRekursive = pObj;
+    SwCacheObj *const pOldRealFirst = pRealFirst;
     while ( pObj )
     {
         // the object must be found also when moving backwards
@@ -48,7 +48,7 @@ void SwCache::Check()
         if ( !pObj->GetNext() )
             SAL_WARN_IF( pObj != pLast, "sw.core", "Last not Found." );
         pObj = pObj->GetNext();
-        SAL_WARN_IF( pObj == pRekursive, "sw.core", "Recursion in SwCache." );
+        SAL_WARN_IF(pObj == pOldRealFirst, "sw.core", "Recursion in SwCache.");
     }
     SAL_WARN_IF( !bFirstFound, "sw.core", "First not Found." );
     SAL_WARN_IF( nCnt + aFreePositions.size() != size(), "sw.core", "Lost Chain." );
diff --git a/sw/source/core/doc/tblrwcl.cxx b/sw/source/core/doc/tblrwcl.cxx
index 2565bf0..95bb03d 100644
--- a/sw/source/core/doc/tblrwcl.cxx
+++ b/sw/source/core/doc/tblrwcl.cxx
@@ -3047,7 +3047,7 @@ static void lcl_ChgBoxSize( SwTableBox& rBox, CR_SetBoxWidth& rParam,
     }
 }
 
-static bool lcl_DeleteBox_Rekursiv( CR_SetBoxWidth& rParam, SwTableBox& rBox,
+static bool lcl_DeleteBox_Recursive( CR_SetBoxWidth& rParam, SwTableBox& rBox,
                             bool bCheck )
 {
     bool bRet = true;
@@ -3075,9 +3075,13 @@ static bool lcl_DeleteBox_Rekursiv( CR_SetBoxWidth& rParam, SwTableBox& rBox,
         {
             SwTableLine& rLine = *rBox.GetTabLines()[ --i ];
             for( sal_uInt16 n = rLine.GetTabBoxes().size(); n; )
-                if( !::lcl_DeleteBox_Rekursiv( rParam,
+            {
+                if (!::lcl_DeleteBox_Recursive( rParam,
                                 *rLine.GetTabBoxes()[ --n ], bCheck ))
+                {
                     return false;
+                }
+            }
         }
     }
     return bRet;
@@ -3203,15 +3207,17 @@ static bool lcl_DelSelBox( SwTableLine* pTabLine, CR_SetBoxWidth& rParam,
                      COLFUZZY > std::abs( rParam.bLeft
                                     ? nWidth - nDist
                                     : (nDist + nWidth - rParam.nTblWidth )))
-                    || !::lcl_DeleteBox_Rekursiv( rParam, *pBox, bCheck ) )
+                    || !::lcl_DeleteBox_Recursive(rParam, *pBox, bCheck))
+                {
                     return false;
+                }
 
                 if( pFmt->GetProtect().IsCntntProtected() )
                     return false;
             }
             else
             {
-                ::lcl_DeleteBox_Rekursiv( rParam, *pBox, bCheck );
+                ::lcl_DeleteBox_Recursive(rParam, *pBox, bCheck);
 
                 if( !rParam.bLeft )
                     --n, --nCntEnd;
commit 31ca7f6d71432081764782ce576cec1fd79e703f
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 12:36:04 2014 +0100

    tools: remove DBG_ERRORFILE and replace all callers
    
    Change-Id: Ic76ccc49b9291fe82c56974eb6237cd3b85d91c8

diff --git a/include/sal/log-areas.dox b/include/sal/log-areas.dox
index 60a1af5..e7f762b 100644
--- a/include/sal/log-areas.dox
+++ b/include/sal/log-areas.dox
@@ -313,6 +313,7 @@ certain functionality.
 @li @c svx.form
 @li @c svx.opengl
 @li @c svx.sdr
+ at li @c svx.sidebar
 @li @c svx.stbcrtls - StatusBarControl
 @li @c svx.svdraw
 @li @c svx.table
diff --git a/include/tools/debug.hxx b/include/tools/debug.hxx
index 050dc34..6e73d2e 100644
--- a/include/tools/debug.hxx
+++ b/include/tools/debug.hxx
@@ -33,7 +33,7 @@
     Because the assertion macro (DBG_ASSERT) has been used for
     true assertions as well as to log warnings, it maps to SAL_WARN instead of
     standard assert.  The warning and error macros (DBG_ASSERTWARNING,
-    DBG_WARNING, DBG_ERRORFILE) all map to
+    DBG_WARNING) all map to
     SAL_INFO.
 */
 
@@ -110,9 +110,6 @@ inline void DbgSetTestSolarMutex( DbgTestSolarMutexProc pProc )
 #define DBG_WARNING( aWarning ) \
     SAL_DETAIL_INFO_IF_FORMAT(true, "legacy.tools", aWarning)
 
-#define DBG_ERRORFILE( aError ) \
-    SAL_DETAIL_INFO_IF_FORMAT(true, "legacy.tools", aError, __FILE__, __LINE__)
-
 #define DBG_TESTSOLARMUTEX()                \
 do                                          \
 {                                           \
@@ -125,7 +122,6 @@ do                                          \
 #define DBG_ASSERTWARNING( sCon, aWarning ) ((void)0)
 #define DBG_ASSERT( sCon, aError ) ((void)0)
 #define DBG_WARNING( aWarning ) ((void)0)
-#define DBG_ERRORFILE( aError ) ((void)0)
 
 #define DBG_TESTSOLARMUTEX() ((void)0)
 
diff --git a/sc/source/filter/excel/tokstack.cxx b/sc/source/filter/excel/tokstack.cxx
index 724b495..cea4a4c 100644
--- a/sc/source/filter/excel/tokstack.cxx
+++ b/sc/source/filter/excel/tokstack.cxx
@@ -526,7 +526,7 @@ bool TokenPool::GetElementRek( const sal_uInt16 nId )
 
     if (nId >= nElementAkt)
     {
-        DBG_ERRORFILE( "*TokenPool::GetElementRek(): nId >= nElementAkt" );
+        SAL_WARN("sc.filter", "*TokenPool::GetElementRek(): nId >= nElementAkt");
 #ifdef DBG_UTIL
         m_nRek--;
 #endif
@@ -535,7 +535,7 @@ bool TokenPool::GetElementRek( const sal_uInt16 nId )
 
     if (pType[ nId ] != T_Id)
     {
-        DBG_ERRORFILE( "-TokenPool::GetElementRek(): pType[ nId ] != T_Id" );
+        SAL_WARN("sc.filter", "-TokenPool::GetElementRek(): pType[ nId ] != T_Id");
 #ifdef DBG_UTIL
         m_nRek--;
 #endif
@@ -547,14 +547,14 @@ bool TokenPool::GetElementRek( const sal_uInt16 nId )
     sal_uInt16 nFirstId = pElement[ nId ];
     if (nFirstId >= nP_Id)
     {
-        DBG_ERRORFILE( "TokenPool::GetElementRek: nFirstId >= nP_Id");
+        SAL_WARN("sc.filter", "TokenPool::GetElementRek: nFirstId >= nP_Id");
         nAnz = 0;
         bRet = false;
     }
     sal_uInt16* pAkt = nAnz ? &pP_Id[ nFirstId ] : NULL;
     if (nAnz > nP_Id - nFirstId)
     {
-        DBG_ERRORFILE( "TokenPool::GetElementRek: nAnz > nP_Id - nFirstId");
+        SAL_WARN("sc.filter", "TokenPool::GetElementRek: nAnz > nP_Id - nFirstId");
         nAnz = nP_Id - nFirstId;
         bRet = false;
     }
@@ -564,7 +564,7 @@ bool TokenPool::GetElementRek( const sal_uInt16 nId )
         {// recursion or not?
             if (*pAkt >= nElementAkt)
             {
-                DBG_ERRORFILE( "TokenPool::GetElementRek: *pAkt >= nElementAkt");
+                SAL_WARN("sc.filter", "TokenPool::GetElementRek: *pAkt >= nElementAkt");
                 bRet = false;
             }
             else
diff --git a/sc/source/filter/excel/xiescher.cxx b/sc/source/filter/excel/xiescher.cxx
index 6d0c56c..4f136ee 100644
--- a/sc/source/filter/excel/xiescher.cxx
+++ b/sc/source/filter/excel/xiescher.cxx
@@ -1598,7 +1598,7 @@ void XclImpChartObj::ReadChartSubStream( XclImpStream& rStrm )
         }
         else
         {
-            DBG_ERRORFILE( "XclImpChartObj::ReadChartSubStream - missing chart substream" );
+            SAL_INFO("sc.filter", "XclImpChartObj::ReadChartSubStream - missing chart substream");
             return;
         }
     }
diff --git a/svx/source/sidebar/paragraph/ParaPropertyPanel.cxx b/svx/source/sidebar/paragraph/ParaPropertyPanel.cxx
index d90aa65..eb8878f 100644
--- a/svx/source/sidebar/paragraph/ParaPropertyPanel.cxx
+++ b/svx/source/sidebar/paragraph/ParaPropertyPanel.cxx
@@ -961,7 +961,7 @@ FieldUnit ParaPropertyPanel::GetCurrentUnit( SfxItemState eState, const SfxPoolI
             }
             else
             {
-                DBG_ERRORFILE( "GetModuleFieldUnit(): no module found" );
+                SAL_WARN("svx.sidebar", "GetModuleFieldUnit(): no module found");
             }
         }
     }
diff --git a/svx/source/sidebar/possize/PosSizePropertyPanel.cxx b/svx/source/sidebar/possize/PosSizePropertyPanel.cxx
index 1c714e8..6956bf6 100644
--- a/svx/source/sidebar/possize/PosSizePropertyPanel.cxx
+++ b/svx/source/sidebar/possize/PosSizePropertyPanel.cxx
@@ -1059,7 +1059,7 @@ FieldUnit PosSizePropertyPanel::GetCurrentUnit( SfxItemState eState, const SfxPo
             }
             else
             {
-                DBG_ERRORFILE( "GetModuleFieldUnit(): no module found" );
+                SAL_WARN("svx.sidebar", "GetModuleFieldUnit(): no module found");
             }
         }
     }
diff --git a/sw/source/filter/ww8/ww8par.cxx b/sw/source/filter/ww8/ww8par.cxx
index 97e7c6b..f3f921e 100644
--- a/sw/source/filter/ww8/ww8par.cxx
+++ b/sw/source/filter/ww8/ww8par.cxx
@@ -350,7 +350,7 @@ void SwWW8ImplReader::ReadEmbeddedData( SvMemoryStream& rStrm, SwDocShell* pDocS
         }
         else
         {
-            DBG_ERRORFILE( "WW8Hyperlink::ReadEmbeddedData - unknown content GUID" );
+            SAL_INFO("sw.ww8", "WW8Hyperlink::ReadEmbeddedData - unknown content GUID");
         }
     }
 
diff --git a/sw/source/uibase/sidebar/PagePropertyPanel.cxx b/sw/source/uibase/sidebar/PagePropertyPanel.cxx
index cc7f5fa..ebe50a6 100644
--- a/sw/source/uibase/sidebar/PagePropertyPanel.cxx
+++ b/sw/source/uibase/sidebar/PagePropertyPanel.cxx
@@ -554,7 +554,7 @@ void PagePropertyPanel::MetricState( SfxItemState eState, const SfxPoolItem* pSt
             }
             else
             {
-                DBG_ERRORFILE( "<PagePropertyPanel::MetricState(..)>: no module found" );
+                SAL_WARN("sw.ui", "<PagePropertyPanel::MetricState(..)>: no module found");
             }
         }
     }
commit 8efc8f6801a0eba4e496595b9ac5a179e953472c
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Oct 28 11:55:05 2014 +0100

    sw: convert some silly assertions and remove stupid debug-only returns
    
    Change-Id: I872cf1b9fada3292724934d608497ecb5f864745

diff --git a/sw/source/core/layout/ftnfrm.cxx b/sw/source/core/layout/ftnfrm.cxx
index 6dbdb68..3f81a9d 100644
--- a/sw/source/core/layout/ftnfrm.cxx
+++ b/sw/source/core/layout/ftnfrm.cxx
@@ -265,19 +265,14 @@ SwTwips SwFtnContFrm::GrowFrm( SwTwips nDist, bool bTst, bool )
     // No check if FixSize since FtnContainer are variable up to their max. height.
     // If the max. height is LONG_MAX, take as much space as needed.
     // If the page is a special footnote page, take also as much as possible.
-#if OSL_DEBUG_LEVEL > 1
-    if ( !GetUpper() || !GetUpper()->IsFtnBossFrm() )
-    { OSL_ENSURE( !this, "no FtnBoss." );
-        return 0;
-    }
-#endif
+    assert(GetUpper() && GetUpper()->IsFtnBossFrm());
 
     SWRECTFN( this )
     if( (Frm().*fnRect->fnGetHeight)() > 0 &&
          nDist > ( LONG_MAX - (Frm().*fnRect->fnGetHeight)() ) )
         nDist = LONG_MAX - (Frm().*fnRect->fnGetHeight)();
 
-    SwFtnBossFrm *pBoss = (SwFtnBossFrm*)GetUpper();
+    SwFtnBossFrm *pBoss = static_cast<SwFtnBossFrm*>(GetUpper());
     if( IsInSct() )
     {
         SwSectionFrm* pSect = FindSctFrm();
@@ -943,16 +938,7 @@ void SwRootFrm::CheckFtnPageDescs( bool bEndNote )
  */
 SwFtnContFrm *SwFtnBossFrm::MakeFtnCont()
 {
-#if OSL_DEBUG_LEVEL > 1
-    if ( FindFtnCont() )
-    {   OSL_ENSURE( !this, "footnote container exists already." );
-    // Insert a footnote container which always sits right after
-    // the body text.
-    // FrmFmt is always the DefaultFrmFmt.
-
-        return 0;
-    }
-#endif
+    SAL_WARN_IF(FindFtnCont(), "sw.core", "footnote container exists already");
 
     SwFtnContFrm *pNew = new SwFtnContFrm( GetFmt()->GetDoc()->GetDfltFrmFmt(), this );
     SwLayoutFrm *pLay = FindBodyCont();
diff --git a/sw/source/core/text/porfly.cxx b/sw/source/core/text/porfly.cxx
index f7d850a..634baa83 100644
--- a/sw/source/core/text/porfly.cxx
+++ b/sw/source/core/text/porfly.cxx
@@ -428,7 +428,7 @@ sal_Int32 SwFlyCntPortion::GetFlyCrsrOfst( const sal_uInt16 nOfst,
 
 sal_Int32 SwFlyCntPortion::GetCrsrOfst( const sal_uInt16 nOfst ) const
 {
-    // OSL_ENSURE( !this, "SwFlyCntPortion::GetCrsrOfst: use GetFlyCrsrOfst()" );
+    // OSL_FAIL("SwFlyCntPortion::GetCrsrOfst: use GetFlyCrsrOfst()");
     return SwLinePortion::GetCrsrOfst( nOfst );
 }
 
diff --git a/sw/source/core/view/viewsh.cxx b/sw/source/core/view/viewsh.cxx
index 53bf408..8d42d63 100644
--- a/sw/source/core/view/viewsh.cxx
+++ b/sw/source/core/view/viewsh.cxx
@@ -993,13 +993,8 @@ void SwViewShell::VisPortChgd( const SwRect &rRect)
     if ( rRect == VisArea() )
         return;
 
-#if OSL_DEBUG_LEVEL > 1
-    if ( mbInEndAction )
-    {
-        //Is someone rescheduling again?
-        OSL_ENSURE( !this, "Scrolling during EndAction." );
-    }
-#endif
+    // Is someone spuriously rescheduling again?
+    SAL_WARN_IF(mbInEndAction, "sw.core", "Scrolling during EndAction");
 
     //First get the old visible page, so we don't have to look
     //for it afterwards.
commit ba3f13151e0ed184966376d7c647ca9e8b592f81
Author: Michael Stahl <mstahl at redhat.com>
Date:   Mon Oct 27 23:20:52 2014 +0100

    sw: prefix members of SwTxtInfo
    
    Change-Id: Ifd3a4e5f4b84b6f8a74e59a7bcdf8ddc35dfe408

diff --git a/sw/source/core/text/inftxt.cxx b/sw/source/core/text/inftxt.cxx
index 7ca7d1d..a03a0be 100644
--- a/sw/source/core/text/inftxt.cxx
+++ b/sw/source/core/text/inftxt.cxx
@@ -154,19 +154,19 @@ void SwLineInfo::CtorInitLineInfo( const SwAttrSet& rAttrSet,
 
 void SwTxtInfo::CtorInitTxtInfo( SwTxtFrm *pFrm )
 {
-    pPara = pFrm->GetPara();
-    nTxtStart = pFrm->GetOfst();
-    if( !pPara )
+    m_pPara = pFrm->GetPara();
+    m_nTxtStart = pFrm->GetOfst();
+    if (!m_pPara)
     {
-        OSL_ENSURE( pPara, "+SwTxtInfo::CTOR: missing paragraph information" );
+        SAL_WARN("sw.core", "+SwTxtInfo::CTOR: missing paragraph information");
         pFrm->Format();
-        pPara = pFrm->GetPara();
+        m_pPara = pFrm->GetPara();
     }
 }
 
 SwTxtInfo::SwTxtInfo( const SwTxtInfo &rInf )
-    : pPara( ((SwTxtInfo&)rInf).GetParaPortion() ),
-      nTxtStart( rInf.GetTxtStart() )
+    : m_pPara( const_cast<SwTxtInfo&>(rInf).GetParaPortion() )
+    , m_nTxtStart( rInf.GetTxtStart() )
 { }
 
 #if OSL_DEBUG_LEVEL > 0
diff --git a/sw/source/core/text/inftxt.hxx b/sw/source/core/text/inftxt.hxx
index 1906201..301a815 100644
--- a/sw/source/core/text/inftxt.hxx
+++ b/sw/source/core/text/inftxt.hxx
@@ -121,21 +121,22 @@ class SwTxtInfo
 {
     // Implementation in txthyph.cxx
     friend void SetParaPortion( SwTxtInfo *pInf, SwParaPortion *pRoot );
-    SwParaPortion *pPara;
-    sal_Int32 nTxtStart; // TxtOfst for Follows
+    SwParaPortion *m_pPara;
+    sal_Int32 m_nTxtStart; // TxtOfst for Follows
 
 protected:
     SwTxtInfo()
-        : pPara(0)
-        , nTxtStart(0)
-        {}
+        : m_pPara(0)
+        , m_nTxtStart(0)
+    {}
+
 public:
     void CtorInitTxtInfo( SwTxtFrm *pFrm );
     SwTxtInfo( const SwTxtInfo &rInf );
     SwTxtInfo( SwTxtFrm *pFrm ) { CtorInitTxtInfo( pFrm ); }
-    SwParaPortion *GetParaPortion() { return pPara; }
-    const SwParaPortion *GetParaPortion() const { return pPara; }
-    sal_Int32 GetTxtStart() const { return nTxtStart; }
+    SwParaPortion *GetParaPortion() { return m_pPara; }
+    const SwParaPortion *GetParaPortion() const { return m_pPara; }
+    sal_Int32 GetTxtStart() const { return m_nTxtStart; }
 
     friend SvStream & WriteSwTxtInfo( SvStream &rOS, const SwTxtInfo &rInf );
 };
diff --git a/sw/source/core/text/txthyph.cxx b/sw/source/core/text/txthyph.cxx
index 6dafd4e..0252788 100644
--- a/sw/source/core/text/txthyph.cxx
+++ b/sw/source/core/text/txthyph.cxx
@@ -119,7 +119,7 @@ bool SwTxtFrm::Hyphenate( SwInterHyphInfo &rHyphInf )
 void SetParaPortion( SwTxtInfo *pInf, SwParaPortion *pRoot )
 {
     OSL_ENSURE( pRoot, "SetParaPortion: no root anymore" );
-    pInf->pPara = pRoot;
+    pInf->m_pPara = pRoot;
 }
 
 bool SwTxtFormatter::Hyphenate( SwInterHyphInfo &rHyphInf )
commit 4023e69403d707d00d39bd3ec5ef4b5292e62ad8
Author: Michael Stahl <mstahl at redhat.com>
Date:   Mon Oct 27 23:03:33 2014 +0100

    sw: translate Netto to Net
    
    Change-Id: Ia9a11eb8266b602c334b774d4794ff71d29754bc

diff --git a/sw/source/core/text/inftxt.cxx b/sw/source/core/text/inftxt.cxx
index 9730e62a..7ca7d1d 100644
--- a/sw/source/core/text/inftxt.cxx
+++ b/sw/source/core/text/inftxt.cxx
@@ -1337,7 +1337,7 @@ void SwTxtFormatInfo::CtorInitTxtFormatInfo( SwTxtFrm *pNewFrm, const bool bNewI
     nForcedLeftMargin = 0;
     pRest = 0;
     nLineHeight = 0;
-    nLineNettoHeight = 0;
+    nLineNetHeight = 0;
     SetLineStart(0);
     Init();
 }
@@ -1443,7 +1443,7 @@ SwTxtFormatInfo::SwTxtFormatInfo( const SwTxtFormatInfo& rInf,
     nRealWidth = sal_uInt16(nActWidth);
     nWidth = nRealWidth;
     nLineHeight = 0;
-    nLineNettoHeight = 0;
+    nLineNetHeight = 0;
     nForcedLeftMargin = 0;
 
     nMinLeading = 0;
@@ -1483,7 +1483,7 @@ bool SwTxtFormatInfo::_CheckFtnPortion( SwLineLayout* pCurr )
         if( pPor->IsFtnPortion() && nHeight > ((SwFtnPortion*)pPor)->Orig() )
         {
             SetLineHeight( nHeight );
-            SetLineNettoHeight( pCurr->Height() );
+            SetLineNetHeight( pCurr->Height() );
             return true;
         }
     }
diff --git a/sw/source/core/text/inftxt.hxx b/sw/source/core/text/inftxt.hxx
index 575cd43..1906201 100644
--- a/sw/source/core/text/inftxt.hxx
+++ b/sw/source/core/text/inftxt.hxx
@@ -538,7 +538,7 @@ class SwTxtFormatInfo : public SwTxtPaintInfo
     sal_uInt16 nRealWidth;      // "real" line width
     sal_uInt16 nWidth;          // "virtual" line width
     sal_uInt16 nLineHeight;     // Final height after CalcLine
-    sal_uInt16 nLineNettoHeight; // line height without spacing
+    sal_uInt16 nLineNetHeight; // line height without spacing
     sal_uInt16 nForcedLeftMargin; // Shift of left margin due to frame
 
     sal_Int16  nMinLeading;     // minimum number of chars before hyphenation point
@@ -651,8 +651,8 @@ public:
     // these are used during fly calculation
     inline sal_uInt16 GetLineHeight() const { return nLineHeight; }
     inline void SetLineHeight( const sal_uInt16 nNew ) { nLineHeight = nNew; }
-    inline sal_uInt16 GetLineNettoHeight() const { return nLineNettoHeight; }
-    inline void SetLineNettoHeight( const sal_uInt16 nNew ) { nLineNettoHeight = nNew; }
+    inline sal_uInt16 GetLineNetHeight() const { return nLineNetHeight; }
+    inline void SetLineNetHeight( const sal_uInt16 nNew ) { nLineNetHeight = nNew; }
 
     inline const SwLinePortion *GetUnderflow() const { return pUnderflow; }
     inline SwLinePortion *GetUnderflow() { return pUnderflow; }
diff --git a/sw/source/core/text/itrform2.cxx b/sw/source/core/text/itrform2.cxx
index 1cd6a83..0d3e80b 100644
--- a/sw/source/core/text/itrform2.cxx
+++ b/sw/source/core/text/itrform2.cxx
@@ -1486,7 +1486,7 @@ sal_Int32 SwTxtFormatter::FormatLine(const sal_Int32 nStartPos)
     bool bBuild = true;
     SetFlyInCntBase( false );
     GetInfo().SetLineHeight( 0 );
-    GetInfo().SetLineNettoHeight( 0 );
+    GetInfo().SetLineNetHeight( 0 );
 
     // Recycling muss bei geaenderter Zeilenhoehe unterdrueckt werden
     // und auch bei geaendertem Ascent (Absenken der Grundlinie).
@@ -2216,7 +2216,7 @@ bool SwTxtFormatter::ChkFlyUnderflow( SwTxtFormatInfo &rInf ) const
                         // RealHeight including spacing
                         rInf.SetLineHeight( nHeight );
                         // Height without extra spacing
-                        rInf.SetLineNettoHeight( pCurr->Height() );
+                        rInf.SetLineNetHeight( pCurr->Height() );
                         return true;
                     }
                 }
@@ -2227,7 +2227,7 @@ bool SwTxtFormatter::ChkFlyUnderflow( SwTxtFormatInfo &rInf ) const
                 if ( ! aInter.IsOver( aLine ) )
                 {
                     rInf.SetLineHeight( nHeight );
-                    rInf.SetLineNettoHeight( pCurr->Height() );
+                    rInf.SetLineNetHeight( pCurr->Height() );
                     return true;
                 }
                 else
@@ -2242,7 +2242,7 @@ bool SwTxtFormatter::ChkFlyUnderflow( SwTxtFormatInfo &rInf ) const
                         ((SwFlyPortion*)pPos)->GetFixWidth() != aInter.Width() )
                     {
                         rInf.SetLineHeight( nHeight );
-                        rInf.SetLineNettoHeight( pCurr->Height() );
+                        rInf.SetLineNetHeight( pCurr->Height() );
                         return true;
                     }
                 }
@@ -2275,7 +2275,7 @@ void SwTxtFormatter::CalcFlyWidth( SwTxtFormatInfo &rInf )
         // Real line height has already been calculated, we only have to
         // search for intersections in the lower part of the strip
         nAscent = pCurr->GetAscent();
-        nHeight = rInf.GetLineNettoHeight();
+        nHeight = rInf.GetLineNetHeight();
         nTop += rInf.GetLineHeight() - nHeight;
     }
     else
diff --git a/sw/source/core/text/porrst.cxx b/sw/source/core/text/porrst.cxx
index 17a30fe..a00a0a7 100644
--- a/sw/source/core/text/porrst.cxx
+++ b/sw/source/core/text/porrst.cxx
@@ -397,7 +397,7 @@ bool SwTxtFrm::FillRegister( SwTwips& rRegStart, sal_uInt16& rRegDiff )
 
                             aFnt.ChgFnt( pSh, *pOut );
                             rRegDiff = aFnt.GetHeight( pSh, *pOut );
-                            sal_uInt16 nNettoHeight = rRegDiff;
+                            sal_uInt16 nNetHeight = rRegDiff;
 
                             switch( rSpace.GetLineSpaceRule() )
                             {
@@ -426,19 +426,19 @@ bool SwTxtFrm::FillRegister( SwTwips& rRegStart, sal_uInt16& rRegDiff )
                                     if( !nTmp )
                                         ++nTmp;
                                     rRegDiff = (sal_uInt16)nTmp;
-                                    nNettoHeight = rRegDiff;
+                                    nNetHeight = rRegDiff;
                                     break;
                                 }
                                 case SVX_INTER_LINE_SPACE_FIX:
                                 {
                                     rRegDiff = rRegDiff + rSpace.GetInterLineSpace();
-                                    nNettoHeight = rRegDiff;
+                                    nNetHeight = rRegDiff;
                                     break;
                                 }
                                 default: OSL_FAIL( ": unknown InterLineSpaceRule" );
                             }
                             pDesc->SetRegHeight( rRegDiff );
-                            pDesc->SetRegAscent( rRegDiff - nNettoHeight +
+                            pDesc->SetRegAscent( rRegDiff - nNetHeight +
                                                  aFnt.GetAscent( pSh, *pOut ) );
                             pOut->SetMapMode( aOldMap );
                         }
diff --git a/sw/source/filter/ww8/ww8par.hxx b/sw/source/filter/ww8/ww8par.hxx
index 96963a2..6e0349b 100644
--- a/sw/source/filter/ww8/ww8par.hxx
+++ b/sw/source/filter/ww8/ww8par.hxx
@@ -886,7 +886,7 @@ private:
 
     SwSectionFmt *InsertSection(SwPaM& rMyPaM, wwSection &rSection);
     bool SetCols(SwFrmFmt &rFmt, const wwSection &rSection,
-        sal_uInt32 nNettoWidth) const;
+        sal_uInt32 nNetWidth) const;
     bool SectionIsProtected(const wwSection &rSection) const;
     void SetLeftRight(wwSection &rSection);
     bool IsNewDoc() const;
diff --git a/sw/source/filter/ww8/ww8par2.hxx b/sw/source/filter/ww8/ww8par2.hxx
index 713eccf..b1d0896 100644
--- a/sw/source/filter/ww8/ww8par2.hxx
+++ b/sw/source/filter/ww8/ww8par2.hxx
@@ -53,7 +53,7 @@ struct WW8SwFlyPara
     sal_Int16 nLeMgn, nRiMgn;       // Raender
     sal_Int16 nUpMgn, nLoMgn;       // Raender
     sal_Int16 nWidth, nHeight;      // Groesse
-    sal_Int16 nNettoWidth;
+    sal_Int16 nNetWidth;
 
     SwFrmSize eHeightFix;       // Hoehe Fix oder Min
     RndStdIds eAnchor;          // Bindung
@@ -66,7 +66,7 @@ struct WW8SwFlyPara
     sal_uInt8 nXBind, nYBind;        // relativ zu was gebunden
 
                 // 2.Teil: sich waehrend des Einlesens ergebende AEnderungen
-    long nNewNettoWidth;
+    long nNewNetWidth;
     SwPosition* pMainTextPos;   // um nach Apo in Haupttext zurueckzukehren
     sal_uInt16 nLineSpace;          // LineSpace in tw fuer Graf-Apos
     bool bAutoWidth;
diff --git a/sw/source/filter/ww8/ww8par6.cxx b/sw/source/filter/ww8/ww8par6.cxx
index 3f3fd8f..0618b42 100644
--- a/sw/source/filter/ww8/ww8par6.cxx
+++ b/sw/source/filter/ww8/ww8par6.cxx
@@ -321,7 +321,7 @@ void SwWW8ImplReader::Read_ParaBiDi(sal_uInt16, const sal_uInt8* pData, short nL
 }
 
 bool wwSectionManager::SetCols(SwFrmFmt &rFmt, const wwSection &rSection,
-    sal_uInt32 nNettoWidth) const
+    sal_uInt32 nNetWidth) const
 {
     //sprmSCcolumns - number of columns - 1
     const sal_Int16 nCols = rSection.NoCols();
@@ -346,7 +346,7 @@ bool wwSectionManager::SetCols(SwFrmFmt &rFmt, const wwSection &rSection,
     }
 
     aCol.Init(nCols, writer_cast<sal_uInt16>(nColSpace),
-        writer_cast<sal_uInt16>(nNettoWidth));
+        writer_cast<sal_uInt16>(nNetWidth));
 
     // sprmSFEvenlySpaced
     if (!rSep.fEvenlySpaced)
@@ -364,7 +364,7 @@ bool wwSectionManager::SetCols(SwFrmFmt &rFmt, const wwSection &rSection,
             pCol->SetLeft(writer_cast<sal_uInt16>(nLeft));
             pCol->SetRight(writer_cast<sal_uInt16>(nRight));
         }
-        aCol.SetWishWidth(writer_cast<sal_uInt16>(nNettoWidth));
+        aCol.SetWishWidth(writer_cast<sal_uInt16>(nNetWidth));
     }
     rFmt.SetFmtAttr(aCol);
     return true;
@@ -1751,7 +1751,7 @@ WW8SwFlyPara::WW8SwFlyPara( SwPaM& rPaM,
     (void) nPgLeft;
 
     memset( this, 0, sizeof( WW8SwFlyPara ) );  // Initialisieren
-    nNewNettoWidth = MINFLY;                    // Minimum
+    nNewNetWidth = MINFLY;                    // Minimum
 
     eSurround = ( rWW.nSp37 > 1 ) ? SURROUND_IDEAL : SURROUND_NONE;
     //#i119466 mapping "Around" wrap setting to "Parallel" for table
@@ -1780,15 +1780,15 @@ WW8SwFlyPara::WW8SwFlyPara( SwPaM& rPaM,
         nHeight = MINFLY;
     }
 
-    nWidth = nNettoWidth = rWW.nSp28;
+    nWidth = nNetWidth = rWW.nSp28;
     if( nWidth <= 10 )                              // Auto-Breite
     {
         bAutoWidth = true;
-        nWidth = nNettoWidth =
+        nWidth = nNetWidth =
             msword_cast<sal_Int16>((nPgWidth ? nPgWidth : 2268)); // 4 cm
     }
     if( nWidth <= MINFLY )
-        nWidth = nNettoWidth = MINFLY;              // Minimale Breite
+        nWidth = nNetWidth = MINFLY;              // Minimale Breite
 
     eVAlign = text::VertOrientation::NONE;                            // Defaults
     eHAlign = text::HoriOrientation::NONE;
@@ -1998,8 +1998,8 @@ WW8SwFlyPara::WW8SwFlyPara( SwPaM& rPaM,
 // ohne Wissen ueber den Inhalt eingesetzt wird.
 void WW8SwFlyPara::BoxUpWidth( long nInWidth )
 {
-    if( bAutoWidth && nInWidth > nNewNettoWidth )
-        nNewNettoWidth = nInWidth;
+    if( bAutoWidth && nInWidth > nNewNetWidth )
+        nNewNetWidth = nInWidth;
 };
 
 // Die Klasse WW8FlySet ist von SfxItemSet abgeleitet und stellt auch
@@ -2505,10 +2505,10 @@ void SwWW8ImplReader::StopApo()
         // function, the extension of the SW-fly has to be set
         // manually as the SW fly has no auto function to adjust the
         // frameĀ“s size.
-        if( pSFlyPara->nNewNettoWidth > MINFLY )    // BoxUpWidth ?
+        if( pSFlyPara->nNewNetWidth > MINFLY )    // BoxUpWidth ?
         {
-            long nW = pSFlyPara->nNewNettoWidth;
-            nW += pSFlyPara->nWidth - pSFlyPara->nNettoWidth;   // Rand dazu
+            long nW = pSFlyPara->nNewNetWidth;
+            nW += pSFlyPara->nWidth - pSFlyPara->nNetWidth;   // Rand dazu
             pSFlyPara->pFlyFmt->SetFmtAttr(
                 SwFmtFrmSize( pSFlyPara->eHeightFix, nW, pSFlyPara->nHeight ) );
         }


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/core/text/itrtxt.cxx b/sw/source/core/text/itrtxt.cxx
index 0aa7075..058a41e 100644
--- a/sw/source/core/text/itrtxt.cxx
+++ b/sw/source/core/text/itrtxt.cxx
@@ -248,11 +248,11 @@ sal_uInt16 SwTxtCursor::AdjustBaseLine( const SwLineLayout& rLine,
                 // centered inside the whole line.
 
                 //for text refactor
-                const sal_uInt16 nLineNetto =  rLine.Height() - nRubyHeight;
-                //const sal_uInt16 nLineNetto = ( nPorHeight > nGridWidth ) ?
+                const sal_uInt16 nLineNet =  rLine.Height() - nRubyHeight;
+                //const sal_uInt16 nLineNet = ( nPorHeight > nGridWidth ) ?
                  //                           rLine.Height() - nRubyHeight :
                  //                           nGridWidth;
-                nOfst += ( nLineNetto - nPorHeight ) / 2;
+                nOfst += ( nLineNet - nPorHeight ) / 2;
                 if ( bRubyTop )
                     nOfst += nRubyHeight;
             }